@@ -97,11 +97,11 @@
     ("V" nil ("$B%W(B" . "$B$W(B")) ("B" nil ("$B%Z(B" . "$B$Z(B"))
     ;;
     ("N" nil ("$B%a(B" . "$B$a(B")) ("M" nil ("$B%=(B" . "$B$=(B")) ("<" nil ("$B%M(B" . "$B$M(B"))
-    (">" nil ("$B%](B" . "$B$](B")) ("?" nil "$B!&(B")) "\
-$BF|K\8l(B 106 $B%-!<%\!<%I$G(B OASYS $BIwF~NO$r$9$k$?$a$N4pK\%k!<%k!#(B")
+    (">" nil ("$B%](B" . "$B$](B")) ("?" nil "$B!&(B"))
+  "$BF|K\8l(B 106 $B%-!<%\!<%I$G(B OASYS $BIwF~NO$r$9$k$?$a$N4pK\%k!<%k!#(B")
 
-(defconst skk-oasys-keymap-display 'dummy "\
-$B0J2<$O!"F|K\8l(B 106 $B%-!<%\!<%I$G(B OASYS $BIwF~NO$r$9$k$?$a$N%-!<G[Ns?^$G$9!#(B
+(defconst skk-oasys-keymap-display 'dummy
+  "$B0J2<$O!"F|K\8l(B 106 $B%-!<%\!<%I$G(B OASYS $BIwF~NO$r$9$k$?$a$N%-!<G[Ns?^$G$9!#(B
 
 $B(#(!(!(((!(!(((!(!(((!(!(((!(!($(B $B(#(!(!(((!(!(((!(!(((!(!(((!(!(((!(!(((!(!($(B
 $B("!!!)("!!!?("!!!A("!!!V("!!!W("(B $B("!!!N("!!!O("!!!J("!!!K("!!!X("!!!Y("!-!!("(B
@@ -124,8 +124,8 @@
  $B1&>e(B $B!D(B $BF1B&?F;X%7%U%H$K$h$jF~NO$5$l$k$Y$-J8;z(B (straight shift)
  $B:8>e(B $B!D(B $BH?BPB&?F;X%7%U%H$K$h$jF~NO$5$l$k$Y$-J8;z(B (cross shift)
 
-($BC"$72<$+$i(B 2 $BNs$a$N1&$N(B 2 $B$D$N%-!<$O$=$l$>$l8eB`%-!<!"<h>C%-!<$G$"$k$3$H$r0UL#(B
-$B$7$^$9!#(B)
+\($BC"$72<$+$i(B 2 $BNs$a$N1&$N(B 2 $B$D$N%-!<$O$=$l$>$l8eB`%-!<!"<h>C%-!<$G$"$k$3$H$r(B
+$B0UL#$7$^$9!#(B)
 
 $B$3$l$K4p$$$F0J2<$N(B 3 $B$D$N%k!<%k$,7hDj$5$l$^$9!#(B
 
@@ -157,8 +157,8 @@
     (?b ("$B%X(B" . "$B$X(B"))
     ;;
     (?n ("$B%a(B" . "$B$a(B")) (?m ("$B%=(B" . "$B$=(B")) (?, ("$B%M(B" . "$B$M(B")) (?. ("$B%[(B" . "$B$[(B"))
-    (?/ "$B!&(B")) "\
-$BC1FHBG80;~$NF~NO%k!<%k!#(B")
+    (?/ "$B!&(B"))
+  "$BC1FHBG80;~$NF~NO%k!<%k!#(B")
 
 (defvar skk-oasys-rshift-rule-list
   '((?1 "$B!)(B") (?2 "$B!?(B") (?3 "$B!A(B") (?4 "$B!V(B") (?5 "$B!W(B")
@@ -185,8 +185,8 @@
     (?n ("$B%L(B" . "$B$L(B")) (?m ("$B%f(B" . "$B$f(B")) (?, ("$B%`(B" . "$B$`(B")) (?. ("$B%o(B" . "$B$o(B"))
     (?/ ("$B!&(B" . "$B$)(B"))
     ;;
-    (?\ " ")) "\
-$B1&?F;X%-!<$,2!$5$l$?$H$-$NF~NO%k!<%k!#(B")
+    (?\ " "))
+  "$B1&?F;X%-!<$,2!$5$l$?$H$-$NF~NO%k!<%k!#(B")
 
 (defvar skk-oasys-lshift-rule-list
   '((?1 "$B!)(B") (?2 "$B!?(B") (?3 "$B!A(B") (?4 "$B!V(B") (?5 "$B!W(B")
@@ -212,8 +212,8 @@
     (?n ("$B%W(B" . "$B$W(B")) (?m ("$B%>(B" . "$B$>(B")) (?, ("$B%Z(B" . "$B$Z(B")) (?. ("$B%\(B" . "$B$\(B"))
     (?/ ("$B!!(B" . skk-kanagaki-dakuten))
     ;;
-    (?\ " ")) "\
-$B:8?F;X%-!<$,2!$5$l$?$H$-$NF~NO%k!<%k!#(B")
+    (?\ " "))
+  "$B:8?F;X%-!<$,2!$5$l$?$H$-$NF~NO%k!<%k!#(B")
 
 (require 'skk-nicola)
 
