@@ -36,7 +36,7 @@
 (defun skk-add-background-color (string color)
   "STRING $B$N$&$AGX7J?'$,;XDj$5$l$F$$$J$$J8;z$K8B$C$F(B COLOR $B$NGX7J?'$r(B
 $BE,MQ$9$k!#(B"
-  (when (eval-when-compile skk-running-gnu-emacs)
+  (when (eval-when-compile (featurep 'emacs))
     (when (and string
 	       color
 	       (color-defined-p color))
@@ -49,42 +49,30 @@
 	  (while (and (< end len)
 		      (eq orig-face (get-text-property end 'face string)))
 	    (incf end))
-	  (cond
-	   ((not orig-face)
-	    (put-text-property start end 'face
-			       `(:background ,color)
-			       string))
-	   ((and (facep orig-face) (not (face-background orig-face)))
-	    (cond
-	     ((eval-when-compile (= emacs-major-version 21))
-	      ;; Emacs 21 $B$G(B :inherit $B$,$&$^$/7Q>5$5$l$J$$!)(B
-	      ;; workaround
-	      (let (attrs)
-		(dolist (pair face-attribute-name-alist)
-		  (let* ((attr (car pair))
-			 (val (face-attribute orig-face attr (selected-frame))))
-		    (unless (eq val 'unspecified)
-		      (setq attrs (cons attr (cons val attrs))))))
-		(put-text-property start end 'face
-				   (append attrs `(:background ,color))
-				   string)))
-	     (t
-	      (put-text-property start end 'face
-				 `(:inherit ,orig-face :background ,color)
-				 string))))
-	   ((and (listp orig-face)
-		 (not (plist-get (get-text-property start 'face string)
-				 :background))
-		 (not (and (plist-get (get-text-property start 'face start)
-				      :inherit)
-			   (face-background
-			    (plist-get (get-text-property start 'face start)
-				       :inherit)))))
-	    (put-text-property start end 'face
-			       (cons
-				`(:background ,color)
-				orig-face)
-			       string)))
+	  (cond ((not orig-face)
+		 (put-text-property start end 'face
+				    `(:background ,color)
+				    string))
+		;;
+		((and (facep orig-face)
+		      (not (face-background orig-face)))
+		 (put-text-property start end 'face
+				    `(:inherit ,orig-face :background ,color)
+				    string))
+		;;
+		((and (listp orig-face)
+		      (not (plist-get (get-text-property start 'face string)
+				      :background))
+		      (not (and (plist-get (get-text-property start 'face start)
+					   :inherit)
+				(face-background
+				 (plist-get (get-text-property start 'face start)
+					    :inherit)))))
+		 (put-text-property start end 'face
+				    (cons `(:background ,color)
+					  orig-face)
+				    string)))
+
 	  (setq start (max (1+ start) end)
 		end (1+ start)))))
     string))
