@@ -5,9 +5,9 @@
 
 ;; Author: Enami Tsugutomo <enami@ba2.so-net.or.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-isearch.el,v 1.71 2011/12/13 00:16:06 skk-cvs Exp $
+;; Version: $Id: skk-isearch.el,v 1.76 2012/12/03 10:36:39 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2011/12/13 00:16:06 $
+;; Last Modified: $Date: 2012/12/03 10:36:39 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -237,7 +237,7 @@ kakutei'ed and erase the buffer contents."
 					    isearch-mode-map))))))
   (set skk-isearch-overriding-local-map skk-isearch-mode-map)
   ;; Input Method $B$H$7$F(B SKK $B$r;H$C$F$$$k>l9g$NBP:v(B
-  (when (eval-when-compile skk-running-gnu-emacs)
+  (when (eval-when-compile (featurep 'emacs))
     (when (and current-input-method
 	       (string-match "^japanese-skk" current-input-method))
       (let* ((method current-input-method)
@@ -246,7 +246,7 @@ kakutei'ed and erase the buffer contents."
 		     'skk-auto-fill-inactivate)))
 	(with-current-buffer (get-buffer-create skk-isearch-working-buffer)
 	  (unless current-input-method
-	    (setq inactivate-current-input-method-function func)
+	    (skk-set-deactivate-im-func func)
 	    (setq current-input-method method))))))
   ;; skk-isearch $B$N>uBV$rI=$9FbItJQ?t$N@_Dj(B
   (setq skk-isearch-switch t)
@@ -289,10 +289,10 @@ kakutei'ed and erase the buffer contents."
       (jisx0208-latin
        (skk-jisx0208-latin-mode-on))))
   ;; Input Method $B$H$7$F(B SKK $B$r;H$C$F$$$k>l9g$NBP:v(B
-  (when (eval-when-compile skk-running-gnu-emacs)
+  (when (eval-when-compile (featurep 'emacs))
     (when (string-match "^japanese-skk" (format "%s" default-input-method))
       (with-current-buffer (get-buffer-create skk-isearch-working-buffer)
-	(inactivate-input-method))))
+	(skk-deactivate-input-method))))
   ;; skk-isearch $B$N>uBV$rI=$9FbItJQ?t$N@_Dj(B
   (setq skk-isearch-switch nil)
   (unless skk-isearch-in-editing
@@ -554,21 +554,30 @@ If the current mode is different from previous, remove it first."
 		  (setq skk-isearch-incomplete-message
 			(skk-isearch-buffer-string))
 		  (skk-isearch-incomplete-message))))))
-    ;;
+
+    ;; isearch-cmds ... Stack of search status sets.
+    ;;   '(["test" "test" 198 198 t 194 nil nil nil 192 t nil]
+    ;;     ["tes" "tes" 197 197 t 194 nil nil nil 192 t nil]
+    ;;     ["te" "te" 196 196 t 194 nil nil nil 192 t nil]
+    ;;     ["t" "t" 195 195 t 194 nil nil nil 192 t nil]
+    ;;     ["" "" 192 t t nil nil nil nil 192 t nil])
+    ;;   or
+    ;;   '([cl-struct-isearch--state "test" "[aa] test" 196 196 t ..]
+    ;;     [cl-struct-isearch--state "tes" "[aa] tes" 195 195 t ..]
+    ;;     [cl-struct-isearch--state "te" "[aa] te" 102 102 t ..]
+    ;;     [cl-struct-isearch--state "t" "[aa] t" 92 92 t ..]
+    ;;     [cl-struct-isearch--state "" "[$B$+(B] " 78 t t ..]
     (let* ((cmd (nth 1 isearch-cmds))
-	   (oldmsg (if (vectorp cmd)
-		       ;; Emacs 21.3.50 $B3+H/HG$G(B `isearch-cmds' $B$N3FMW(B
-		       ;; $BAG$N7A<0$,(B list $B$+$i(B vector $B$KJQ99$K$J$C$F$7(B
-		       ;; $B$^$C$?$N$G(B workaround $B$r$*$/!#0J2<F1MM!#(B
-		       (aref cmd 1)
-		     (cadr cmd)))
+	   (oldmsg (if (stringp (aref cmd 0))
+		       (aref cmd 1)	;GNU Emacs 24.2 $B$^$G(B
+		     (aref cmd 2)))	;GNU Emacs 24.3 $B$+$i(B
 	   (prompt (skk-isearch-mode-string))
 	   newmsg)
       (unless (or (null cmd)
 		  (string-match (concat "^" (regexp-quote prompt))
 				oldmsg))
-	;; `skk-isearch-delete-char'$B$,8F$P$l$kA0$K(B `skk-isearch-working-buffer'
-	;; $BFb$N%b!<%I$,@Z$jBX$($i$l$F$$$?>l9g!"(B isearch-cmds  $B$NBh(B 2 $BMWAG$K$D$$(B
+	;; `skk-isearch-delete-char' $B$,8F$P$l$kA0$K(B `skk-isearch-working-buffer'
+	;; $BFb$N%b!<%I$,@Z$jBX$($i$l$F$$$?>l9g!"(B isearch-cmds $B$NBh(B 2 $BMWAG$K$D$$(B
 	;; $B$F!"(B messege $B$NFbMF$r(B update $B$7$J$$$H(B [DEL] $B$7$?$H$-$N%b!<%I$NI=<($,(B
 	;; $B$*$+$7$/$J$k!#(B
 	(do ((alist skk-isearch-mode-string-alist (cdr alist))
@@ -578,9 +587,10 @@ If the current mode is different from previous, remove it first."
 			(substring oldmsg (match-end 0)))))
 	    ((or msg (null alist))
 	     (setq newmsg (concat prompt (or msg oldmsg)))
-	     (if (vectorp cmd)
-		 (aset cmd 1 newmsg)
-	       (setcdr cmd (cons newmsg (cddr cmd))))))))
+	     (if (stringp (aref cmd 0))
+		 (aset cmd 1 newmsg)	;GNU Emacs 24.2 $B$^$G(B
+	       (aset cmd 2 newmsg))	;GNU Emacs 24.3 $B$+$i(B
+	     ))))
     (isearch-delete-char)))
 
 (defun skk-isearch-kakutei (isearch-function)
@@ -791,7 +801,7 @@ If the current mode is different from previous, remove it first."
 	       (let ((skk-isearch-initial-mode-when-skk-mode-disabled
 		      'latin))
 		 (skk-isearch-mode-setup))
-	       (inactivate-input-method)))
+	       (skk-deactivate-input-method)))
 	    (t
 	     ad-do-it)))))
 
