@@ -7,9 +7,9 @@
 
 ;; Author: Masahiko Sato <masahiko@kuis.kyoto-u.ac.jp>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-kcode.el,v 1.101 2011/12/17 04:46:50 skk-cvs Exp $
+;; Version: $Id: skk-kcode.el,v 1.107 2012/11/26 12:51:12 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2011/12/17 04:46:50 $
+;; Last Modified: $Date: 2012/11/26 12:51:12 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -33,7 +33,6 @@
 ;;; Code:
 
 (eval-when-compile
-  ;;   (require 'font-lock)
   (require 'cl)
   (require 'skk-macs)
   (require 'skk-vars)
@@ -434,17 +433,16 @@ To find a character in `%s', type 7/8 bits JIS code (00nn),\
 
 ;;;###autoload
 (defun skk-display-code-for-char-at-point (&optional arg)
-  "$B%]%$%s%H$K$"$kJ8;z$N6hE@HV9f!"(BJIS $B%3!<%I!"(BEUC $B%3!<%I5Z$S%7%U%H(B JIS $B%3!<%I(B\
- $B$rI=<($9$k!#(B"
+  "$B%]%$%s%H$K$"$kJ8;z$N6hE@HV9f!"(BJIS $B%3!<%I!"(BEUC $B%3!<%I!"%7%U%H(B JIS $B%3!<%I(B\
+$B5Z$S%f%K%3!<%I$rI=<($9$k!#(B"
   (interactive)
   (if (eobp)
       (skk-message "$B%+!<%=%k$,%P%C%U%!$N=*C<$K$"$j$^$9(B"
 		   "Cursor is at the end of the buffer")
-    (skk-display-code (following-char)))
+    (skk-display-code (following-char) (point)))
   t) ; $B%(%3!<$7$?J8;zNs$r%+%l%s%H%P%C%U%!$KA^F~$7$J$$$h$&$K!#(B
 
-(defun skk-display-code (char)
-;;   (require 'font-lock)
+(defun skk-display-code (char p)
   (let ((charset (skk-char-charset char skk-charset-list))
 	mesg)
     (cond
@@ -466,12 +464,13 @@ To find a character in `%s', type 7/8 bits JIS code (00nn),\
 	     (char-data (skk-tankan-get-char-data char))
 	     (anno (skk-tankan-get-char-annotation char))
 	     (unicode (cond ((eval-when-compile
-			       (and skk-running-gnu-emacs
+			       (and (featurep 'emacs)
 				    (>= emacs-major-version 23)))
 			     (concat ", "
 				     (propertize "UNICODE:" 'face
 						 'skk-display-code-prompt-face)
 				     (format "U+%04x" char)))
+
 			    ((and (eval-when-compile (fboundp 'char-to-ucs))
 				  (fboundp 'char-to-ucs)
 				  (char-to-ucs char))
@@ -479,9 +478,19 @@ To find a character in `%s', type 7/8 bits JIS code (00nn),\
 				     (propertize "UNICODE:" 'face
 						 'skk-display-code-prompt-face)
 				     (format "U+%04x" (char-to-ucs char))))
+
+			    ((and (eval-when-compile (fboundp 'encode-char))
+				  (fboundp 'encode-char)
+				  (encode-char char 'ucs))
+			     (concat ", "
+				     (propertize "UNICODE:" 'face
+						 'skk-display-code-prompt-face)
+				     (format "U+%04x" (encode-char char 'ucs))))
+
 			    (t
-			     ""))))
-	;;
+			     "")))
+	     (composition (find-composition p nil nil t)))
+
 	(setq mesg
 	      (concat (propertize (char-to-string char)
 				  'face 'skk-display-code-char-face)
@@ -501,6 +510,10 @@ To find a character in `%s', type 7/8 bits JIS code (00nn),\
 		      (format "#x%2x%2x" char1-s char2-s)
 
 		      unicode
+		      (if composition
+			  (format " (Composed with U+%x)"
+				  (string-to-char
+				   (buffer-substring (1+ p) (nth 1 composition)))))
 		      (unless (zerop (nth 2 char-data))
 			(concat ", "
 				(propertize
@@ -516,7 +529,7 @@ To find a character in `%s', type 7/8 bits JIS code (00nn),\
 				   anno
 				   'face
 				   'skk-display-code-tankan-annotation-face)))
-			   ))))
+		      ))))
      ;;
      ((memq charset '(ascii latin-jisx0201))
       (setq mesg
@@ -526,10 +539,14 @@ To find a character in `%s', type 7/8 bits JIS code (00nn),\
 		    (propertize "DECIMAL:" 'face 'skk-display-code-prompt-face)
 		    (format "%3d" (skk-char-octet char 0)))))
      ;;
+     ((eq (char-charset char) 'unicode)
+      (setq mesg (format "UNICODE: U+%04x" char))) ;$BMW(Bmule-ucs(emacs22)$BBP1~(B
+     ;;
      (t
-      (setq mesg (if skk-japanese-message-and-error
-		     "$BH=JL$G$-$J$$J8;z$G$9(B"
-		   "Cannot understand this character"))))
+      (setq mesg (format (if skk-japanese-message-and-error
+			     "$BJ8;z=89g(B %s $B$O%5%]!<%H$7$F$$$^$;$s(B"
+			   "%s character set is not supported")
+			 (char-charset char)))))
     ;;
     (cond
      ((and window-system
@@ -661,7 +678,7 @@ To find a character in `%s', type 7/8 bits JIS code (00nn),\
     (if (eq 'ascii (car (split-char c)))
 	;; $B6h@Z$j9T$J$I$G(B $ $B$5$l$?>l9g(B
 	(next-completion 1)
-      (skk-display-code c))))
+      (skk-display-code c (point)))))
 
 (defun skk-list-chars-copy ()
   (interactive)
