@@ -4,9 +4,9 @@
 ;; Copyright (C) 1993-2000 Free Software Foundation, Inc.
 
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-macs.el,v 1.181 2011/12/27 13:07:18 skk-cvs Exp $
+;; Version: $Id: skk-macs.el,v 1.192 2013/01/13 09:45:48 skk-cvs Exp $
 ;; Keywords: japanese, mule, input method
-;; Last Modified: $Date: 2011/12/27 13:07:18 $
+;; Last Modified: $Date: 2013/01/13 09:45:48 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -41,11 +41,11 @@
 
 ;;;; macros
 
-(when (eval-when-compile (and skk-running-gnu-emacs
-			      (<= emacs-major-version 22)))
+(when (eval-when-compile (and (featurep 'emacs)
+			      (= emacs-major-version 22)))
   (defmacro ignore-errors (&rest body)
-    "Execute FORMS; if an error occurs, return nil.
-Otherwise, return result of last FORM."
+    "Execute BODY; if an error occurs, return nil.
+Otherwise, return result of last form in BODY."
     `(condition-case nil
 	 (progn
 	   ,@body)
@@ -151,15 +151,15 @@ doesn't give arguments of `interactive'. See `interactive' for details."
 `yes-or-no-p' $B$N0z?t(B PROMPT $B$,J#;($KF~$l9~$s$G$$$k>l9g$O(B `skk-yes-or-no-p' $B$r(B
 $B;H$&$h$j$b%*%j%8%J%k$N(B `yes-or-no-p' $B$r;HMQ$7$?J}$,%3!<%I$,J#;($K$J$i$J$$>l9g(B
 $B$,$"$k!#(B"
- (list 'yes-or-no-p (list 'if 'skk-japanese-message-and-error
-				   japanese english)))
+  (list 'yes-or-no-p (list 'if 'skk-japanese-message-and-error
+			   japanese english)))
 
 (defmacro skk-y-or-n-p (japanese english)
   "$B%f!<%6$K(B \"y or n\" $B$r<ALd$7!"Ez$($,(B \"y\" $B$@$C$?$i(B t $B$rJV$9!#(B
 `skk-japanese-message-and-error' $B$,(B non-nil $B$G$"$l$P(B JAPANESE $B$r!"(B nil $B$G$"$l(B
 $B$P(B ENGLISH $B$r(B PROMPT $B$H$7$F(B `y-or-n-p' $B$r<B9T$9$k!#(B"
   (list 'y-or-n-p (list 'if 'skk-japanese-message-and-error
-				japanese english)))
+			japanese english)))
 
 (defmacro skk-set-marker (marker position &optional buffer)
   "$B%^!<%+(B MARKER $B$r(B BUFFER $B$N(B POSITION $B$K0\F0$9$k!#(B
@@ -223,9 +223,8 @@ MARKER $B$,(B nil $B$@$C$?$i!"?75,%^!<%+!<$r:n$C$FBeF~$9$k!#(B"
 	 ,@body))))
 
 (defmacro skk-called-interactively-p (&optional kind)
-  (cond ((or (featurep 'xemacs)
-	     (= emacs-major-version 21))
-	 ;; XEmacs and GNU Emacs 21
+  (cond ((featurep 'xemacs)
+	 ;; XEmacs
 	 ;; `called-interactively-p' is not defined.
 	 '(interactive-p))
 
@@ -251,37 +250,57 @@ MARKER $B$,(B nil $B$@$C$?$i!"?75,%^!<%+!<$r:n$C$FBeF~$9$k!#(B"
        (delete-overlay o))
      (setq ,list nil)))
 
+(defmacro skk-set-deactivate-im-func (func)
+  (cond ((boundp 'deactivate-current-input-method-function)
+	 ;; GNU Emacs 24.2 $B$+$i(B
+	 `(setq deactivate-current-input-method-function ,func))
+
+	(t
+	 ;; GNU Emacs 24.1 $B$^$G(B
+	 `(setq inactivate-current-input-method-function ,func))
+	))
+
+(defmacro skk-deactivate-input-method ()
+  (cond ((fboundp 'deactivate-input-method)
+	 ;; GNU Emacs 24.2 $B$+$i(B
+	 '(deactivate-input-method))
+	(t
+	 ;; GNU Emacs 24.1 $B$^$G(B
+	 '(inactivate-input-method))
+	))
+
+
 ;;; functions.
 ;; version dependent
 ;; Many functions are derived from emu (APEL).
 
-(when (eval-when-compile (and skk-running-gnu-emacs
-			      (<= emacs-major-version 22)))
+(when (eval-when-compile (and (featurep 'emacs)
+			      (= emacs-major-version 22)))
   (defalias 'characterp 'char-valid-p))
 
-(when (eval-when-compile skk-running-gnu-emacs)
+(when (eval-when-compile (featurep 'emacs))
   (defalias 'int-char 'identity))
 
-(when (eval-when-compile skk-running-gnu-emacs)
+(when (eval-when-compile (featurep 'emacs))
   (defun string-to-char-list (string)
     "Return a list of which elements are characters in the STRING."
     (mapcar #'identity string)))
 
-(when (eval-when-compile skk-running-gnu-emacs)
+(when (eval-when-compile (featurep 'emacs))
   (defalias 'string-to-int-list 'string-to-char-list))
 
 (when (eval-when-compile (featurep 'xemacs))
   (defun string-to-int-list (str)
     (mapcar #'char-int str)))
 
-(when (eval-when-compile skk-running-gnu-emacs)
+(when (eval-when-compile (featurep 'emacs))
   (defun character-to-event (ch)
     "Convert keystroke CH into an event structure, replete with bucky bits.
 Note that CH (the keystroke specifier) can be an integer, a character
 or a symbol such as 'clear."
     ch))
 
-(when (eval-when-compile skk-running-gnu-emacs)
+(when (eval-when-compile (featurep 'emacs))
   (defun event-to-character (event)
     "Return the character approximation to the given event object.
 If the event isn't a keypress, this returns nil."
@@ -296,15 +315,14 @@ If the event isn't a keypress, this returns nil."
      ((integerp event)
       event))))
 
-(when (eval-when-compile skk-running-gnu-emacs)
+(when (eval-when-compile (featurep 'emacs))
   (defun cancel-undo-boundary ()
     "Cancel undo boundary."
     (if (and (consp buffer-undo-list)
 	     (null (car buffer-undo-list)))
 	(setq buffer-undo-list (cdr buffer-undo-list)))))
 
-(unless (eval-when-compile (and skk-running-gnu-emacs
-				(>= emacs-major-version 22)))
+(when (eval-when-compile (featurep 'xemacs))
   (defun substring-no-properties (string &optional from to)
     "Return a substring of string, without text properties.
 It starts at index from and ending before to.
@@ -380,7 +398,7 @@ and replace a sub-expression, e.g.
 	(apply #'concat (nreverse matches))))))
 
 ;; For GNU Emacs.
-(when (eval-when-compile skk-running-gnu-emacs)
+(when (eval-when-compile (featurep 'emacs))
   (defun next-command-event (&optional event prompt)
     "Read an event object from the input stream.
 If EVENT is non-nil, it should be an event object and will be filled
@@ -400,18 +418,6 @@ but the contents viewed as characters do change.
 \[Emacs 20.3 emulating function]"
   flag))
 
-(defun skk-sit-for (seconds &optional nodisplay)
-  "`sit-for' $B$N(B Emacsen $B$K$h$k0c$$$r5[<}$9$k!#(B"
-  (cond
-   ((eval-when-compile (featurep 'xemacs))
-    (sit-for seconds nodisplay))
-   ((eval-when-compile (= emacs-major-version 21))
-    ;; GNU Emacs 21
-    (sit-for seconds nil nodisplay))
-   (t
-    ;; GNU Emacs 22.1 or later
-    (sit-for seconds nodisplay))))
-
 (defun skk-ding (&optional arg sound device)
   "`ding' $B$N(B Emacsen $B$K$h$k0c$$$r5[<}$9$k!#(B"
   (cond
@@ -424,7 +430,7 @@ but the contents viewed as characters do change.
   (cond
    ((eval-when-compile (featurep 'xemacs))
     (eq (device-class (selected-device)) 'color))
-   ((eval-when-compile skk-running-gnu-emacs)
+   ((eval-when-compile (featurep 'emacs))
     (and (skk-find-window-system)
 	 (fboundp 'x-display-color-p)
 	 (x-display-color-p)))))
@@ -432,7 +438,7 @@ but the contents viewed as characters do change.
 (defun skk-char-to-unibyte-string (char)
   (ignore-errors
     (cond
-     ((eval-when-compile (and skk-running-gnu-emacs
+     ((eval-when-compile (and (featurep 'emacs)
 			      (>= emacs-major-version 23)))
       ;; GNU Emacs 23.1 or later
       (string-make-unibyte (char-to-string char)))
@@ -441,7 +447,7 @@ but the contents viewed as characters do change.
 
 (defun skk-ascii-char-p (char)
   (cond
-   ((eval-when-compile (and skk-running-gnu-emacs
+   ((eval-when-compile (and (featurep 'emacs)
 			    (>= emacs-major-version 23)))
     ;; GNU Emacs 23.1 or later
     (eq (char-charset char skk-charset-list) 'ascii))
@@ -450,7 +456,7 @@ but the contents viewed as characters do change.
 
 (defun skk-jisx0208-p (char)
   (cond
-   ((eval-when-compile (and skk-running-gnu-emacs
+   ((eval-when-compile (and (featurep 'emacs)
 			    (>= emacs-major-version 23)))
     ;; GNU Emacs 23.1 or later
     (eq (char-charset char skk-charset-list) 'japanese-jisx0208))
@@ -459,7 +465,7 @@ but the contents viewed as characters do change.
 
 (defun skk-jisx0213-p (char)
   (cond
-   ((eval-when-compile (and skk-running-gnu-emacs
+   ((eval-when-compile (and (featurep 'emacs)
 			    (>= emacs-major-version 23)))
     ;; GNU Emacs 23.1 or later
     (memq (char-charset char skk-charset-list)
@@ -467,14 +473,14 @@ but the contents viewed as characters do change.
 	    japanese-jisx0213.2004-1
 	    japanese-jisx0213-2)))
    (t
-    (and (featurep 'jisx0213)
+    (and (featurep 'jisx0213)		; Mule-UCS
 	 (memq (char-charset char)
 	       '(japanese-jisx0213-1 japanese-jisx0213-2))))))
 
 (defun skk-split-char (ch)
   ;; http://mail.ring.gr.jp/skk/200908/msg00006.html
   (cond
-   ((eval-when-compile (and skk-running-gnu-emacs
+   ((eval-when-compile (and (featurep 'emacs)
 			    (>= emacs-major-version 23)))
     ;; C $B$N(B split-char() $B$HF1MM$N5!G=$@$,!"(Bchar-charset() $B$N8F=P$7$K$*$$$F(B
     ;; $BJ8;z=89g$NA*Br;h$r(B skk-charset-list $B$K4^$^$l$k$b$N$K@)8B$9$k!#(B
@@ -491,12 +497,12 @@ but the contents viewed as characters do change.
 	(setq dimension (1- dimension)))
       (cons charset val)))
    (t
-    ;; Emacs 22 $B0JA0!"$*$h$S(B XEmacs
+    ;; Emacs 22 $B$*$h$S(B XEmacs
     (split-char ch))))
 
 (defun skk-char-charset (ch &optional restriction)
   (cond
-   ((eval-when-compile (and skk-running-gnu-emacs
+   ((eval-when-compile (and (featurep 'emacs)
 			    (>= emacs-major-version 23)))
     ;; GNU Emacs 23.1 or later
     (char-charset ch restriction))
@@ -518,14 +524,12 @@ but the contents viewed as characters do change.
     (if (stringp indicator)
 	indicator
       (cdr indicator)))
-   ((eval-when-compile (>= emacs-major-version 21))
+   (t
     (if no-properties
 	(with-temp-buffer
 	  (insert indicator)
 	  (buffer-substring-no-properties (point-min) (point-max)))
-      indicator))
-   (t
-    indicator)))
+      indicator))))
 
 (defun skk-mode-string-to-indicator (mode string)
   "$BJ8;zNs(B STRING $B$r(B SKK $B%$%s%8%1!<%?7?%*%V%8%'%/%H$KJQ49$9$k!#(B"
@@ -593,13 +597,13 @@ BUFFER defaults to the current buffer."
 
 (defun skk-region-active-p ()
   (cond
-   ((eval-when-compile (and skk-running-gnu-emacs
+   ((eval-when-compile (and (featurep 'emacs)
 			    (>= emacs-major-version 23)))
     (use-region-p))
    ((eval-when-compile (featurep 'xemacs))
     (region-active-p))
    (t
-    ;; GNU Emacs 21 and 22.
+    ;; GNU Emacs 22.
     (and transient-mark-mode mark-active))))
 
 (put 'skk-bind-last-command-char 'lisp-indent-function 1)
@@ -614,8 +618,7 @@ BUFFER defaults to the current buffer."
 
 (defun skk-process-kill-without-query (process)
   (cond
-   ((eval-when-compile (and skk-running-gnu-emacs
-			    (>= emacs-major-version 22)))
+   ((eval-when-compile (featurep 'emacs))
     (set-process-query-on-exit-flag process nil))
    (t
     (process-kill-without-query process))))
@@ -673,9 +676,9 @@ BUFFER defaults to the current buffer."
 ;;(defsubst skk-get-char (tree)
 ;;  (car tree))
 ;;
-;; skk-current-rule-tree $B$KBP$7$FGK2uE*$JA`:n$O9T$J$($J$$!#(Bskk-rule-tree $B$N(B
-;; $BFbMF$^$GJQ$o$C$F$7$^$$!"(Bskk-current-rule-tree $B$N(B initialize $B$,<j7Z$K9T$J(B
-;; $B$($J$/$J$k!#$3$3$,2r7h$G$-$l$P(B skk-prefix $B$rA4LG$G$-$k$N$K(B...$B!#(B
+;; skk-current-rule-tree $B$KBP$7$FGK2uE*$JA`:n$O9T$($J$$!#(Bskk-rule-tree $B$N(B
+;; $BFbMF$^$GJQ$o$C$F$7$^$$!"(Bskk-current-rule-tree $B$N(B initialize $B$,<j7Z$K9T$((B
+;; $B$J$/$J$k!#$3$3$,2r7h$G$-$l$P(B skk-prefix $B$rA4LG$G$-$k$N$K(B...$B!#(B
 ;;(defsubst skk-set-char (tree char)
 ;;  (setcar tree char))
 ;;
@@ -860,13 +863,8 @@ BUFFER defaults to the current buffer."
   (cond
    ((eval-when-compile (featurep 'xemacs))
     nil) ; XEmacs $B$G%5%]!<%H$5$l$J$$5!G=(B
-   ((eval-when-compile (and skk-running-gnu-emacs
-			      (>= emacs-major-version 22)))
-    (window-body-height)) ; emacs21 $B$K$O$J$$(B
    (t
-    (- (window-height)
-       (if mode-line-format 1 0)
-       (if header-line-format 1 0)))))
+    (window-body-height)))) ; emacs21 $B$K$O$J$$(B
 
 (defun skk-screen-column ()
   "$B%9%/%j!<%s9T$+$iF@$?%+!<%=%k0LCV$N7e?t$rJV$9!#(B
@@ -918,7 +916,7 @@ BUFFER defaults to the current buffer."
 $BBP$7$F(B emacs-mule $B$N(B encoded string $B$KJQ49$7$FHf3S$9$k!#(B
 $BHf3S$N7k2L(B str1 < str2 $B$J$i$P(B t $B$rJV$9!#(B"
   (cond
-   ((eval-when-compile (and skk-running-gnu-emacs
+   ((eval-when-compile (and (featurep 'emacs)
 			    (>= emacs-major-version 23)))
     ;; Emacs with coding system utf-8-emacs
     (skk-string-lessp-in-coding-system str1 str2 'emacs-mule))
