@@ -3,10 +3,10 @@
 
 ;; Author: NAKAJIMA Mikio <minakaji@namazu.org>
 ;; Maintainer: SKK Development Team <skk@ring.gr.jp>
-;; Version: $Id: skk-study.el,v 1.63 2011/06/03 23:35:25 skk-cvs Exp $
+;; Version: $Id: skk-study.el,v 1.66 2013/01/13 09:45:48 skk-cvs Exp $
 ;; Keywords: japanese
 ;; Created: Apr. 11, 1999
-;; Last Modified: $Date: 2011/06/03 23:35:25 $
+;; Last Modified: $Date: 2013/01/13 09:45:48 $
 
 ;; This file is part of Daredevil SKK.
 
@@ -89,15 +89,15 @@
        (ring-ref skk-study-data-ring index)))
 
 (defsubst skk-study-get-current-alist (&optional theme)
-  (let ((base-alist
-	 (cdr (if theme
-		  (assoc theme skk-study-alist)
-		(or (assoc skk-study-current-buffer-theme
-			   skk-study-alist)
-		    (assoc "general" skk-study-alist))))))
+  (let ((base-alist (cdr (if theme
+			     (assoc theme skk-study-alist)
+			   (or (assoc skk-study-current-buffer-theme
+				      skk-study-alist)
+			       (assoc "general" skk-study-alist))))))
     (assq (cond ((or skk-okuri-char skk-henkan-okurigana)
 		 'okuri-ari)
-		(t 'okuri-nasi)) base-alist)))
+		(t 'okuri-nasi))
+	  base-alist)))
 
 (add-to-list 'skk-search-end-function 'skk-study-search)
 (add-to-list 'skk-update-end-function 'skk-study-update)
@@ -193,57 +193,59 @@
 
 ;;;###autoload
 (defun skk-study-save (&optional nomsg)
-  "`skk-study-file' $B$K3X=,7k2L$rJ]B8$9$k!#(B
-$B%*%W%7%g%J%k0z?t$N(B NOMSG $B$,(B non-nil $B$G$"$l$P!"J]B8%a%C%;!<%8$r=PNO$7$J$$!#(B"
+  "$B3X=,7k2L$r(B `skk-study-file' $B$XJ]B8$9$k!#(B
+$B%*%W%7%g%J%k0z?t$N(B NOMSG $B$,(B non-nil $B$G$"$l$P!"J]B8%a%C%;!<%8$rI=<($7$J$$!#(B"
   (interactive "P")
+  (if (or (and (null skk-study-alist) (not nomsg))
+	  (not skk-study-last-read)
+	  (and skk-study-last-save
+	       (skk-study-time-lessp
+		skk-study-last-save skk-study-last-read)))
+      (progn
+	(skk-message "SKK $B$N3X=,7k2L$r%;!<%V$9$kI,MW$O$"$j$^$;$s(B"
+		     "No SKK study need saving")
+	(sit-for 1))
+    (skk-study-save-1 nomsg)))
+
+(defun skk-study-save-1 (nomsg)
   (let ((inhibit-quit t)
 	e)
-    (if (or (and (null skk-study-alist) (not nomsg))
-	    (not skk-study-last-read)
-	    (and skk-study-last-save
-		 (skk-study-time-lessp
-		  skk-study-last-save skk-study-last-read)))
-	(progn
-	  (skk-message "SKK $B$N3X=,7k2L$r%;!<%V$9$kI,MW$O$"$j$^$;$s(B"
-		       "No SKK study need saving")
-	  (sit-for 1))
-      (when (not nomsg)
-	(skk-message "%s $B$K(B SKK $B$N3X=,7k2L$r%;!<%V$7$F$$$^$9(B..."
-		     "Saving SKK study to %s..." skk-study-file))
-      (and skk-study-backup-file
-	   (file-exists-p (expand-file-name skk-study-file))
-	   (cond ((eq system-type 'ms-dos)
-		  (with-temp-file skk-study-backup-file
-		    (erase-buffer)
-		    (insert-file-contents skk-study-file)))
-		 (t
-		  (copy-file (expand-file-name skk-study-file)
-			     (expand-file-name skk-study-backup-file)
-			     'ok-if-already-exists 'keep-date))))
-      (with-temp-buffer
-	(insert
-	 (format ";;; skk-study-file format version %s\n"
-		 skk-study-file-format-version))
-	(when skk-study-sort-saving
-	  ;; sort is not necessary, but make an alist rather readable.
-	  (setq e (assq 'okuri-ari skk-study-alist))
-	  (setcdr e (sort (cdr e)
-			  (lambda (a b)
-				      (skk-string< (car a) (car b)))))
-	  (setq e (assq 'okuri-nasi skk-study-alist))
-	  (setcdr e (sort (cdr e)
-			  (lambda (a b)
-				      (skk-string< (car a) (car b))))))
-	(skk-study-prin1 skk-study-alist (current-buffer))
-	(let ((coding-system-for-write (skk-find-coding-system skk-jisyo-code))
-	      jka-compr-compression-info-list)
-	  (write-region (point-min) (point-max) skk-study-file)))
-      (setq skk-study-last-save (current-time))
-      (when (not nomsg)
-	(skk-message "%s $B$K(B SKK $B$N3X=,7k2L$r%;!<%V$7$F$$$^$9(B...$B40N;!*(B"
-		     "Saving SKK study to %s...done" skk-study-file)
-	(sit-for 1)
-	(message "")))))
+    (when (not nomsg)
+      (skk-message "SKK $B$N3X=,7k2L$r(B %s $B$K%;!<%V$7$F$$$^$9(B..."
+		   "Saving SKK study to %s..." skk-study-file))
+    (and skk-study-backup-file
+	 (file-exists-p (expand-file-name skk-study-file))
+	 (cond ((eq system-type 'ms-dos)
+		(with-temp-file skk-study-backup-file
+		  (erase-buffer)
+		  (insert-file-contents skk-study-file)))
+	       (t
+		(copy-file (expand-file-name skk-study-file)
+			   (expand-file-name skk-study-backup-file)
+			   'ok-if-already-exists 'keep-date))))
+    (with-temp-buffer
+      (insert (format ";;; skk-study-file format version %s\n"
+		      skk-study-file-format-version))
+      (when skk-study-sort-saving
+	;; sort is not necessary, but make an alist rather readable.
+	(setq e (assq 'okuri-ari skk-study-alist))
+	(setcdr e (sort (cdr e)
+			(lambda (a b)
+			  (skk-string< (car a) (car b)))))
+	(setq e (assq 'okuri-nasi skk-study-alist))
+	(setcdr e (sort (cdr e)
+			(lambda (a b)
+			  (skk-string< (car a) (car b))))))
+      (skk-study-prin1 skk-study-alist (current-buffer))
+      (let ((coding-system-for-write (skk-find-coding-system skk-jisyo-code))
+	    jka-compr-compression-info-list)
+	(write-region (point-min) (point-max) skk-study-file)))
+    (setq skk-study-last-save (current-time))
+    (when (not nomsg)
+      (skk-message "SKK $B$N3X=,7k2L$r(B %s $B$K%;!<%V$7$F$$$^$9(B...$B40N;!*(B"
+		   "Saving SKK study to %s...done" skk-study-file)
+      (sit-for 1)
+      (message ""))))
 
 ;;;###autoload
 (defun skk-study-switch-current-theme (theme)
@@ -281,36 +283,34 @@
 			(cons e n))
 		      (mapcar 'car skk-study-alist))))
 	  nil 'require-match)))
-  (when (string= theme "general")
-    (skk-error "\"general\" $B%F!<%^$O:o=|$G$-$^$;$s(B"
-	       "Cannot remove theme \"general\""))
-  (setq skk-study-alist (delq (assoc theme skk-study-alist)
-			      skk-study-alist))
-  (when (and skk-study-current-buffer-theme
-	     (string= skk-study-current-buffer-theme theme))
-    (setq skk-study-current-buffer-theme nil)))
+  (if (string= theme "general")
+      (skk-message "$B3X=,%F!<%^(B `general' $B$O:o=|$G$-$^$;$s(B"
+		 "Cannot remove skk-study theme `general'")
+    (setq skk-study-alist (delq (assoc theme skk-study-alist)
+				skk-study-alist))
+    (when (and skk-study-current-buffer-theme
+	       (string= skk-study-current-buffer-theme theme))
+      (setq skk-study-current-buffer-theme nil))))
 
 ;;;###autoload
 (defun skk-study-copy-theme (from to)
   "skk-study $B$N3X=,%F!<%^(B FROM $B$r(B TO $B$K%3%T!<$9$k!#(B
 TO $B$N4{B8%G!<%?$OGK2u$5$l$k!#(B"
   (interactive
-   (list (completing-read
-	  "Copy skk-study theme from: "
-	  (when (or skk-study-alist (skk-study-read))
-	    (let ((n 0))
-	      (mapcar (lambda (e)
-			(setq n (1+ n))
-			(cons e n))
-		      (mapcar 'car skk-study-alist))))
-	  nil 'require-match)
-	 (completing-read
-	  "Copy skk-study theme to: "
-	  (let ((n 0))
-	    (mapcar (lambda (e)
-		      (setq n (1+ n))
-		      (cons e n))
-		    (mapcar 'car skk-study-alist))))))
+   (list (completing-read "Copy skk-study theme from: "
+			  (when (or skk-study-alist (skk-study-read))
+			    (let ((n 0))
+			      (mapcar (lambda (e)
+					(setq n (1+ n))
+					(cons e n))
+				      (mapcar 'car skk-study-alist))))
+			  nil 'require-match)
+	 (completing-read "Copy skk-study theme to: "
+			  (let ((n 0))
+			    (mapcar (lambda (e)
+				      (setq n (1+ n))
+				      (cons e n))
+				    (mapcar 'car skk-study-alist))))))
   (when (string= from to)
     (skk-error "$B%3%T!<85$H%3%T!<@h$N%F!<%^$,F10l$G$9(B"
 	       "FROM and TO is the same theme"))
@@ -318,7 +318,7 @@ TO $B$N4{B8%G!<%?$OGK2u$5$l$k!#(B"
 	(toalist (assoc to skk-study-alist)))
     (unless fromalist
       (skk-error "$B%3%T!<85$N3X=,%G!<%?$,$"$j$^$;$s(B"
-	       "FROM study data is null"))
+		 "FROM study data is null"))
     (if toalist
 	(setcdr toalist fromalist)
       (setq skk-study-alist (cons (cons to fromalist) skk-study-alist)))))
@@ -328,12 +328,11 @@ TO $B$N4{B8%G!<%?$OGK2u$5$l$k!#(B"
   "`skk-study-file' $B$+$i3X=,7k2L$rFI$_9~$`!#(B
 $B%*%W%7%g%J%k0z?t$N(B FORCE $B$,(B non-nil $B$G$"$l$P!"GK4~$N3NG'$r$7$J$$!#(B"
   (interactive "P")
-  (skk-create-file
-   skk-study-file
-   (if (not nomsg)
-       (if skk-japanese-message-and-error
-	   "SKK $B$N3X=,7k2L%U%!%$%k$r:n$j$^$7$?(B"
-	 "I have created an SKK study file for you")))
+  (skk-create-file skk-study-file
+		   (if (not nomsg)
+		       (if skk-japanese-message-and-error
+			   "SKK $B$N3X=,7k2L%U%!%$%k$r:n$j$^$7$?(B"
+			 "I have created an SKK study file for you")))
   (when (or (null skk-study-alist)
 	    force
 	    (skk-yes-or-no-p
@@ -348,9 +347,8 @@ TO $B$N4{B8%G!<%?$OGK2u$5$l$k!#(B"
     (setq skk-study-alist (skk-study-read-1 skk-study-file))
     (setq skk-study-last-read (current-time))
     (when (and skk-study-alist (not nomsg))
-      (skk-message
-       "%s $B$N(B SKK $B3X=,7k2L$rE83+$7$F$$$^$9(B...$B40N;!*(B"
-       "Expanding SKK study of %s ...done"
+      (skk-message "%s $B$N(B SKK $B3X=,7k2L$rE83+$7$F$$$^$9(B...$B40N;!*(B"
+		   "Expanding SKK study of %s ...done"
        (file-name-nondirectory skk-study-file))
       (sit-for 1)
       (message ""))))
@@ -387,14 +385,13 @@ TO $B$N4{B8%G!<%?$OGK2u$5$l$k!#(B"
    (list (read-file-name
 	  (format "File to check: (default: %s) " skk-study-file)
 	  default-directory skk-study-file)))
-  (skk-message "%s $B$N%U%)!<%^%C%H$N%A%'%C%/$r9T$J$C$F$$$^$9(B..."
+  (skk-message "%s $B$N%U%)!<%^%C%H$r%A%'%C%/$7$F$$$^$9(B..."
 	       "Checking format of %s..." file)
   (or (skk-study-check-alist-format-1 (skk-study-read-1 file))
       (skk-error "%s $B$N%U%)!<%^%C%H$O2u$l$F$$$^$9(B"
 		 "%s format is broken" file))
-  (skk-message
-   "%s $B$N%U%)!<%^%C%H$N%A%'%C%/$r9T$J$C$F$$$^$9(B...$B40N;(B!"
-   "Checking format of %s...done" file)
+  (skk-message "%s $B$N%U%)!<%^%C%H$r%A%'%C%/$7$F$$$^$9(B...$B40N;(B!"
+	       "Checking format of %s...done" file)
   (sit-for 1)
   (message ""))
 
